==> nextcloud-18.0.3.tgz: nextcloud/3rdparty/symfony/polyfill-iconv/Resources/charset/from.iso-8859-3.php <==
<?php

static $data = array (
  ' ' => ' ',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '	' => '	',
  '
' => '
',
  '' => '',
  '' => '',
  '
' => '
',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  ' ' => ' ',
  '!' => '!',
  '"' => '"',
  '#' => '#',
  '$' => '$',
  '%' => '%',
  '&' => '&',
  '\'' => '\'',
  '(' => '(',
  ')' => ')',
  '*' => '*',
  '+' => '+',
  ',' => ',',
  '-' => '-',
  '.' => '.',
  '/' => '/',
  0 => '0',
  1 => '1',
  2 => '2',
  3 => '3',
  4 => '4',
  5 => '5',
  6 => '6',
  7 => '7',
  8 => '8',
  9 => '9',
  ':' => ':',
  ';' => ';',
  '<' => '<',
  '=' => '=',
  '>' => '>',
  '?' => '?',
  '@' => '@',
  'A' => 'A',
  'B' => 'B',
  'C' => 'C',
  'D' => 'D',
  'E' => 'E',
  'F' => 'F',
  'G' => 'G',
  'H' => 'H',
  'I' => 'I',
  'J' => 'J',
  'K' => 'K',
  'L' => 'L',
  'M' => 'M',
  'N' => 'N',
  'O' => 'O',
  'P' => 'P',
  'Q' => 'Q',
  'R' => 'R',
  'S' => 'S',
  'T' => 'T',
  'U' => 'U',
  'V' => 'V',
  'W' => 'W',
  'X' => 'X',
  'Y' => 'Y',
  'Z' => 'Z',
  '[' => '[',
  '\\' => '\\',
  ']' => ']',
  '^' => '^',
  '_' => '_',
  '`' => '`',
  'a' => 'a',
  'b' => 'b',
  'c' => 'c',
  'd' => 'd',
  'e' => 'e',
  'f' => 'f',
  'g' => 'g',
  'h' => 'h',
  'i' => 'i',
  'j' => 'j',
  'k' => 'k',
  'l' => 'l',
  'm' => 'm',
  'n' => 'n',
  'o' => 'o',
  'p' => 'p',
  'q' => 'q',
  'r' => 'r',
  's' => 's',
  't' => 't',
  'u' => 'u',
  'v' => 'v',
  'w' => 'w',
  'x' => 'x',
  'y' => 'y',
  'z' => 'z',
  '{' => '{',
  '|' => '|',
  '}' => '}',
  '~' => '~',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => ' ',
  '' => 'Ħ',
  '' => '˘',
  '' => '£',
  '' => '¤',
  '' => 'Ĥ',
  '' => '§',
  '' => '¨',
  '' => 'İ',
  '' => 'Ş',
  '' => 'Ğ',
  '' => 'Ĵ',
  '' => '­',
  '' => 'Ż',
  '' => '°',
  '' => 'ħ',
  '' => '²',
  '' => '³',
  '' => '´',
  '' => 'µ',
  '' => 'ĥ',
  '' => '·',
  '' => '¸',
  '' => 'ı',
  '' => 'ş',
  '' => 'ğ',
  '' => 'ĵ',
  '' => '½',
  '' => 'ż',
  '' => 'À',
  '' => 'Á',
  '' => 'Â',
  '' => 'Ä',
  '' => 'Ċ',
  '' => 'Ĉ',
  '' => 'Ç',
  '' => 'È',
  '' => 'É',
  '' => 'Ê',
  '' => 'Ë',
  '' => 'Ì',
  '' => 'Í',
  '' => 'Î',
  '' => 'Ï',
  '' => 'Ñ',
  '' => 'Ò',
  '' => 'Ó',
  '' => 'Ô',
  '' => 'Ġ',
  '' => 'Ö',
  '' => '×',
  '' => 'Ĝ',
  '' => 'Ù',
  '' => 'Ú',
  '' => 'Û',
  '' => 'Ü',
  '' => 'Ŭ',
  '' => 'Ŝ',
  '' => 'ß',
  '' => 'à',
  '' => 'á',
  '' => 'â',
  '' => 'ä',
  '' => 'ċ',
  '' => 'ĉ',
  '' => 'ç',
  '' => 'è',
  '' => 'é',
  '' => 'ê',
  '' => 'ë',
  '' => 'ì',
  '' => 'í',
  '' => 'î',
  '' => 'ï',
  '' => 'ñ',
  '' => 'ò',
  '' => 'ó',
  '' => 'ô',
  '' => 'ġ',
  '' => 'ö',
  '' => '÷',
  '' => 'ĝ',
  '' => 'ù',
  '' => 'ú',
  '' => 'û',
  '' => 'ü',
  '' => 'ŭ',
  '' => 'ŝ',
  '' => '˙',
);

$result =& $data;
unset($data);

return $result;

==> nextcloud-25.0.11.tgz: nextcloud/3rdparty/symfony/polyfill-iconv/Resources/charset/from.iso-8859-6.php <==
<?php

static $data = array (
  ' ' => ' ',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '	' => '	',
  '
' => '
',
  '' => '',
  '' => '',
  '
' => '
',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  ' ' => ' ',
  '!' => '!',
  '"' => '"',
  '#' => '#',
  '$' => '$',
  '%' => '%',
  '&' => '&',
  '\'' => '\'',
  '(' => '(',
  ')' => ')',
  '*' => '*',
  '+' => '+',
  ',' => ',',
  '-' => '-',
  '.' => '.',
  '/' => '/',
  0 => '0',
  1 => '1',
  2 => '2',
  3 => '3',
  4 => '4',
  5 => '5',
  6 => '6',
  7 => '7',
  8 => '8',
  9 => '9',
  ':' => ':',
  ';' => ';',
  '<' => '<',
  '=' => '=',
  '>' => '>',
  '?' => '?',
  '@' => '@',
  'A' => 'A',
  'B' => 'B',
  'C' => 'C',
  'D' => 'D',
  'E' => 'E',
  'F' => 'F',
  'G' => 'G',
  'H' => 'H',
  'I' => 'I',
  'J' => 'J',
  'K' => 'K',
  'L' => 'L',
  'M' => 'M',
  'N' => 'N',
  'O' => 'O',
  'P' => 'P',
  'Q' => 'Q',
  'R' => 'R',
  'S' => 'S',
  'T' => 'T',
  'U' => 'U',
  'V' => 'V',
  'W' => 'W',
  'X' => 'X',
  'Y' => 'Y',
  'Z' => 'Z',
  '[' => '[',
  '\\' => '\\',
  ']' => ']',
  '^' => '^',
  '_' => '_',
  '`' => '`',
  'a' => 'a',
  'b' => 'b',
  'c' => 'c',
  'd' => 'd',
  'e' => 'e',
  'f' => 'f',
  'g' => 'g',
  'h' => 'h',
  'i' => 'i',
  'j' => 'j',
  'k' => 'k',
  'l' => 'l',
  'm' => 'm',
  'n' => 'n',
  'o' => 'o',
  'p' => 'p',
  'q' => 'q',
  'r' => 'r',
  's' => 's',
  't' => 't',
  'u' => 'u',
  'v' => 'v',
  'w' => 'w',
  'x' => 'x',
  'y' => 'y',
  'z' => 'z',
  '{' => '{',
  '|' => '|',
  '}' => '}',
  '~' => '~',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => '',
  '' => ' ',
  '' => '¤',
  '' => '،',
  '' => '­',
  '' => '؛',
  '' => '؟',
  '' => 'ء',
  '' => 'آ',
  '' => 'أ',
  '' => 'ؤ',
  '' => 'إ',
  '' => 'ئ',
  '' => 'ا',
  '' => 'ب',
  '' => 'ة',
  '' => 'ت',
  '' => 'ث',
  '' => 'ج',
  '' => 'ح',
  '' => 'خ',
  '' => 'د',
  '' => 'ذ',
  '' => 'ر',
  '' => 'ز',
  '' => 'س',
  '' => 'ش',
  '' => 'ص',
  '' => 'ض',
  '' => 'ط',
  '' => 'ظ',
  '' => 'ع',
  '' => 'غ',
  '' => 'ـ',
  '' => 'ف',
  '' => 'ق',
  '' => 'ك',
  '' => 'ل',
  '' => 'م',
  '' => 'ن',
  '' => 'ه',
  '' => 'و',
  '' => 'ى',
  '' => 'ي',
  '' => 'ً',
  '' => 'ٌ',
  '' => 'ٍ',
  '' => 'َ',
  '' => 'ُ',
  '' => 'ِ',
  '' => 'ّ',
  '' => 'ْ',
);

$result =& $data;
unset($data);

return $result;
